This is the README file for the project.

this package include some modules which simply wrapper python known packages or modules,
such as wx, logging and also include utils helping do some other things.

2017.08.02:
    0.1.2:
        1.add decorator 'singletion' for generation of python class'ssingleton pattern.
2018.10.09:
    0.1.3:
        1.remove wxpython helper
        2.support python3


